@@ -37,9 +37,11 @@ from .shape import *
 from .solve import *
 from .sqrt import *
 from .squeeze import *
+from .submatrix import *
 from .subtract import *
 from .sum import *
 from .take import *
+from .tile import *
 from .to_numpy import *
 from .trace import *
 from .transpose import *
