@@ -2,8 +2,8 @@ import lab as B
 
 from ..diagonal import Diagonal
 from ..kronecker import Kronecker
-from ..matrix import Dense
 from ..lowrank import LowRank
+from ..matrix import Dense
 from ..woodbury import Woodbury
 
 __all__ = []
@@ -25,13 +25,16 @@ def inv(a: Woodbury):
     # Explicitly computing the inverse is not great numerically, but solving
     # against left or right destroys symmetry, which hinders further algebraic
     # simplifications.
-    return B.subtract(diag_inv, LowRank(
-        B.matmul(diag_inv, a.lr.left),
-        B.matmul(diag_inv, a.lr.right),
-        B.inv(B.schur(a))
-    ))
+    return B.subtract(
+        diag_inv,
+        LowRank(
+            B.matmul(diag_inv, a.lr.left),
+            B.matmul(diag_inv, a.lr.right),
+            B.inv(B.schur(a)),
+        ),
+    )
 
 
 @B.dispatch
 def inv(a: Kronecker):
-    return Kronecker(B.inv(a.left), B.inv(a.right))
\ No newline at end of file
+    return Kronecker(B.inv(a.left), B.inv(a.right))
