@@ -1,6 +1,4 @@
 import lab as B
-import numpy as np
-from wbml.warning import warn_upmodule
 
 from ..woodbury import Woodbury
 
@@ -27,4 +25,4 @@ B.sample = sample
 
 @B.dispatch
 def sample(a: Woodbury, num=1):
-    return B.sample(a.diag, num=num) + B.sample(a.lr, num=num)
\ No newline at end of file
+    return B.sample(a.diag, num=num) + B.sample(a.lr, num=num)
