@@ -167,9 +167,9 @@ def assert_compatible(x1, x2):
         x1 (object): First object.
         x2 (object): Second object.
     """
-    assert compatible(x1, x2), (
-        f"Objects {x1} and {x2} are asserted to be compatible, but they are not."
-    )
+    assert compatible(
+        x1, x2
+    ), f"Objects {x1} and {x2} are asserted to be compatible, but they are not."
 
 
 @dispatch
@@ -196,4 +196,4 @@ def broadcast(s1: Shape, s2: Shape):
 def broadcast(d1: Dimension, d2: Dimension):
     if not compatible(d1, d2):
         raise RuntimeError(f"Cannot broadcast dimensions {d1} and {d2}.")
-    return d2 if d1.size == 1 else d1
\ No newline at end of file
+    return d2 if d1.size == 1 else d1
