@@ -3,7 +3,7 @@ import lab as B
 from matrix import Dense
 
 # noinspection PyUnresolvedReferences
-from ..util import allclose, check_bin_op, dense1, dense2
+from ..util import approx, check_bin_op, dense1, dense2
 
 
 def test_subtract_dense(dense1, dense2):
