@@ -1,4 +1,6 @@
 import lab as B
+import pytest
+
 from matrix import Diagonal
 
 # noinspection PyUnresolvedReferences
@@ -20,3 +22,8 @@ def test_diagonal_attributes():
 
 def test_conversion_to_diagonal(dense1):
     approx(Diagonal(dense1), B.diag(B.diag(dense1)))
+
+
+def test_diagonal_checks():
+    with pytest.raises(AssertionError):
+        Diagonal(B.ones(3, 3))
